@@ -32,7 +32,6 @@
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
-//#include <libgnomeprintui/gnome-print-preview.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
 #include "application.h"
 #include "globals.h"
@@ -111,41 +110,23 @@ static void on_view_close(GtkWidget *widget, gcApplication *app)
 	app->OnViewClose();
 }
 
-static void on_about()
+void on_about()
 {
 	char * authors[]={"Jean Bréfort",NULL};
 	char * documentors[] = {NULL};
 	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/pixmaps/gnome-crystal-logo.png", NULL);
-/*Note for translators: please add an acute accent to the e in Brefort*/
 	char * translators = _(\
-"Jean Brefort <jean.brefort@ac-dijon.fr>: French\n\
+"Jean Bréfort <jean.brefort@ac-dijon.fr>: French\n\
 Tigrux <tigrux@avantel.net>: Spanish\n\
 Costantino Ceoldo <inverness1@virgilio.it>: Italian"
 			);
 	GtkWidget* about = gnome_about_new(_("Gnome Crystal"), VERSION,
-/*Note for translators: please add an acute accent to the e in Brefort*/
-										_("(C) 1999-2001 by Jean Brefort"),
+										_("(C) 1999-2001 by Jean Bréfort"),
 										_("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
 										(const gchar**) authors, (const gchar**) documentors, translators, pixbuf);
 	gtk_widget_show_all(about);
 }
 
-static void on_help()
-{
-/*	gchar* helpfile = gnome_help_file_find_file("gcrystal", "index.html");
-	if (helpfile != NULL)
-	{
-		gchar* url = g_strconcat("ghelp:", helpfile, NULL);
-		gnome_help_goto(NULL, url);
-		g_free(url);
-		g_free(helpfile);
-	}
-	else
-	{
-		gnome_error_dialog(_("Couldn't find the Gnome Crystal manual"));
-	}*/
-}
-
 static void on_lattice(GtkWidget *widget, gcApplication *app)
 {
 	if (app) app->OnCrystalDefine(0);
@@ -156,7 +137,7 @@ static void on_atoms(GtkWidget *widget, gcApplication *app)
 	if (app) app->OnCrystalDefine(1);
 }
 
-static void on_bonds(GtkWidget *widget, gcApplication *app)
+static void on_lines(GtkWidget *widget, gcApplication *app)
 {
 	if (app) app->OnCrystalDefine(2);
 }
@@ -262,7 +243,7 @@ static bool do_load(const gchar* filename, gcView* pView)
 	return false;
 }
 
-static void do_save_as(const gchar* filename, gcView* pView)
+void do_save_as(const gchar* filename, gcView* pView)
 {
 	gcDocument *pDoc = pView->GetDocument();
 	pDoc->SetFileName(filename);
@@ -270,7 +251,7 @@ static void do_save_as(const gchar* filename, gcView* pView)
 }
 
 #ifdef HAVE_LIBJPEG
-static void do_export_jpeg(const gchar *filename, gcView* pView)
+void do_export_jpeg(const gchar *filename, gcView* pView)
 {
 	if (!pView) return;
 	pView->ExportJPG(filename);
@@ -278,14 +259,14 @@ static void do_export_jpeg(const gchar *filename, gcView* pView)
 #endif
 
 #ifdef HAVE_PNG
-static void do_export_png(const gchar *filename, gcView* pView)
+void do_export_png(const gchar *filename, gcView* pView)
 {
 	if (!pView) return;
 	pView->ExportPNG(filename);
 }
 #endif
 
-static void do_export_vrml(const gchar *filename, gcView* pView)
+void do_export_vrml(const gchar *filename, gcView* pView)
 {
 	gcDocument *pDoc = pView->GetDocument();
 	if (pDoc) pDoc->OnExportVRML(filename, pView);;
@@ -321,85 +302,103 @@ bool RequestApp(gcView* pView)
 
 //Implementation of gcApplication class
 
+static GnomeUIInfo export_menu [] = {
+	GNOMEUIINFO_ITEM_NONE(N_("VRML"), N_("Export to VRML"), on_export_vrml),
+#ifdef HAVE_PNG
+#endif
+	GNOMEUIINFO_ITEM_NONE(N_("PNG"), N_("Export view to png file"), on_export_png),
+#ifdef HAVE_LIBJPEG
+	GNOMEUIINFO_ITEM_NONE(N_("Jpeg"), N_("Export view to jpeg file"), on_export_jpeg),
+#endif
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo file_menu [] = {
+	GNOMEUIINFO_MENU_NEW_ITEM(N_("_New File"), N_("Create a new file"), on_file_new, NULL),
+	GNOMEUIINFO_MENU_OPEN_ITEM(on_file_open, NULL),
+	{ GNOME_APP_UI_ITEM, N_("O_pen in a new window..."),
+		N_("Open a file in a new window"), (gpointer)on_file_save_as, NULL, NULL, \
+		GNOME_APP_PIXMAP_NONE, NULL, 'o', (GdkModifierType)(GDK_CONTROL_MASK | GDK_SHIFT_MASK), NULL },
+	GNOMEUIINFO_MENU_SAVE_ITEM(on_file_save, NULL),
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM(on_file_save_as, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_SUBTREE_HINT(N_("_Export"), N_("Export data or graphics"), export_menu),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_PRINT_ITEM(on_file_print, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_CLOSE_ITEM(on_file_close, NULL),
+	GNOMEUIINFO_MENU_EXIT_ITEM(on_quit, NULL),
+	GNOMEUIINFO_END
+};
+ 
+static GnomeUIInfo edit_menu [] = {
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM(on_prefs, NULL),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo crystal_menu [] = {
+	GNOMEUIINFO_ITEM_NONE(N_("_Lattice..."), N_("Define the lattice"), on_lattice),
+	GNOMEUIINFO_ITEM_NONE(N_("_Atoms..."), N_("Define the lattice"), on_atoms),
+	GNOMEUIINFO_ITEM_NONE(N_("_Bonds and lines..."), N_("Add bonds and lines"), on_lines),
+	GNOMEUIINFO_ITEM_NONE(N_("_Size..."), N_("Define size"), on_size),
+	GNOMEUIINFO_ITEM_NONE(N_("_Cleavages..."), N_("Add cleavages to remove some planes"), on_cleavages),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo view_menu [] = {
+	GNOMEUIINFO_ITEM_NONE(N_("View _settings..."), N_("Choose background color and model position"), on_view_settings),
+	GNOMEUIINFO_END
+};
+static GnomeUIInfo windows_menu [] = {
+	GNOMEUIINFO_MENU_NEW_WINDOW_ITEM(on_view_new, NULL),
+	GNOMEUIINFO_MENU_CLOSE_WINDOW_ITEM(on_view_close, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_END
+};
+ 
+static GnomeUIInfo help_menu [] = {
+	GNOMEUIINFO_HELP((void*)"gnome-crystal"),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(on_about, NULL),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo main_menu [] = {
+	GNOMEUIINFO_MENU_FILE_TREE(&file_menu),
+	GNOMEUIINFO_MENU_EDIT_TREE(&edit_menu),
+	GNOMEUIINFO_SUBTREE(N_("_Crystal"), &crystal_menu),
+	GNOMEUIINFO_MENU_VIEW_TREE(&view_menu),
+	GNOMEUIINFO_MENU_WINDOWS_TREE(&windows_menu),
+	GNOMEUIINFO_MENU_HELP_TREE(&help_menu),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo tool_bar [] = {
+	GNOMEUIINFO_ITEM_STOCK(N_("New"), N_("Create a new file"), on_file_new, GTK_STOCK_NEW),
+	GNOMEUIINFO_ITEM_STOCK(N_("Open"), N_("Open a file"), on_file_open, GTK_STOCK_OPEN),
+	GNOMEUIINFO_ITEM_STOCK(N_("Save"), N_("Save active file"), on_file_save, GTK_STOCK_SAVE),
+	GNOMEUIINFO_ITEM_STOCK(N_("Print"), N_("Print active view"), on_file_print, GTK_STOCK_PRINT),
+	GNOMEUIINFO_ITEM_STOCK(N_("Close"), N_("Close active file"), on_file_close, GTK_STOCK_CLOSE),
+	GNOMEUIINFO_ITEM_STOCK(N_("Quit"), N_("Quit Gnome Crystal"), on_quit, GTK_STOCK_QUIT),
+	GNOMEUIINFO_END
+};
+
 gcApplication::gcApplication()
 {
-	GladeXML *xml ;
-	xml = glade_xml_new(DATADIR"/gcrystal/glade/application.glade", "app", NULL);
-
-
-	m_App = glade_xml_get_widget(xml, "app");
+	m_App = gnome_app_new(_("Gnome Crystal"), _("Gnome Crystal"));
+	gnome_app_create_menus_with_data((GnomeApp*)m_App, main_menu, this);
+	gnome_app_create_toolbar_with_data((GnomeApp*)m_App, tool_bar, this);
+	m_WindowsMenu = GTK_MENU(windows_menu[0].widget->parent);
+	GtkWidget *bar = gnome_appbar_new(true, true, GNOME_PREFERENCES_ALWAYS);
+	gnome_appbar_set_default(GNOME_APPBAR(bar), _("Ready."));
+	gnome_app_set_statusbar((GnomeApp*)m_App, bar);
+	gnome_app_install_appbar_menu_hints(GNOME_APPBAR(bar), main_menu);
 	g_signal_connect(G_OBJECT(m_App), "delete_event", (GtkSignalFunc)on_delete, this);
-	g_signal_connect(G_OBJECT(m_App), "destroy", (GtkSignalFunc)on_destroy, this);
-	m_Notebook = GTK_NOTEBOOK(glade_xml_get_widget(xml, "notebook"));
-	g_signal_connect(G_OBJECT(m_Notebook), "switch_page", (GtkSignalFunc)on_change_page, this); 
-
-	m_WindowsMenu = (GtkMenu*) ((glade_xml_get_widget(xml, "Placeholder"))->parent);	//Connect callbacks to menu items
-	GObject *obj;
-	obj = G_OBJECT(glade_xml_get_widget(xml, "exit"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_quit, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "quit_btn"));
-	g_signal_connect(obj, "clicked", (GtkSignalFunc)on_quit, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "new"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_new, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "new_btn"));
-	g_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_new, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "open"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_open, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "open_btn"));
-	g_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_open, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "open_new_win"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_open_new_win, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "save"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_save, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "save_btn"));
-	g_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_save, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "save_as"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_save_as, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "close"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_close, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "close_btn"));
-	g_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_close, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "print"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_file_print, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "vrml"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_export_vrml, this);
-	obj = G_OBJECT(glade_xml_get_widget(xml, "jpeg"));
-#ifdef HAVE_LIBJPEG
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_export_jpeg, this); 
-#else
-	gtk_widget_hide(GTK_WIDGET(obj));
-#endif
-	obj = G_OBJECT(glade_xml_get_widget(xml, "png"));
-#ifdef HAVE_PNG
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_export_png, this); 
-#else
-	gtk_widget_hide(GTK_WIDGET(obj));
-#endif
-	obj = G_OBJECT(glade_xml_get_widget(xml, "print_btn"));
-	g_signal_connect(obj, "clicked", (GtkSignalFunc)on_file_print, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "lattice"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_lattice, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "atoms"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_atoms, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "bonds"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_bonds, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "size"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_size, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "cleavages"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_cleavages, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "view_settings"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_view_settings, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "preferences"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_prefs, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "new_view"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_view_new, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "close_view"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_view_close, this); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "about"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_about, NULL); 
-	obj = G_OBJECT(glade_xml_get_widget(xml, "manual"));
-	g_signal_connect(obj, "activate", (GtkSignalFunc)on_help, NULL); 
+	g_signal_connect(G_OBJECT(m_App), "destroy", G_CALLBACK(on_destroy), NULL);
+	m_Notebook = GTK_NOTEBOOK(gtk_notebook_new());
+	gtk_widget_set_size_request(GTK_WIDGET(m_Notebook), 300, 300);
+	gnome_app_set_contents((GnomeApp*)m_App, GTK_WIDGET(m_Notebook));
 	UpdateConfig();
+	gtk_widget_show_all(m_App);
 }
 
 gcApplication::~gcApplication()
@@ -510,7 +509,7 @@ void gcApplication::OnViewSettings()
 void gcApplication::OnFilePrint()
 {
 	GnomePrintConfig* config = gnome_print_config_default();
-	GnomePrintContext *pc;// = gnome_print_context_new(config);
+	GnomePrintContext *pc;
 	GnomePrintJob *gpj = gnome_print_job_new(config);
 	int do_preview, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
@@ -528,16 +527,11 @@ void gcApplication::OnFilePrint()
 		gtk_widget_destroy (GTK_WIDGET(gpd));
 		return;
 	}
-//	GnomePrintConfig *gpc = gnome_print_dialog_get_config (GNOME_PRINT_DIALOG (gpd));
 	gtk_widget_destroy(GTK_WIDGET(gpd));
-//	gpm = gnome_print_master_new_from_config (gpc);
 	pc = gnome_print_job_get_context (gpj);
 	gnome_print_beginpage(pc, (const guchar*)"");
 	gdouble width, height;
-	gnome_print_job_get_page_size_from_config(config, &width, &height);//FIXME: should work
-printf("paper size: width:%g height:%g\n",width,height);
-	width = 595.2755906;//suppose A4
-	height = 841.8897638;
+	gnome_print_job_get_page_size_from_config(config, &width, &height);
 	m_pActiveView->Print(pc, width, height);
 	gnome_print_showpage(pc);
 	g_object_unref(pc);
